@@ -64,6 +64,15 @@ class browser:
             self.add_and_print_log('Setting text on element ' + identifier, add_log)
         element.send_keys(text)
 
+    def try_find_element(self, by, identifier, add_log = True):
+        try:
+            self.wait_visible_element(by, identifier)
+            self.driver.find_element(by, identifier)
+        except:
+            return False
+        else:
+            return True
+
     def find_element(self, by, identifier, add_log = True):
         self.wait_visible_element(by, identifier)
         return self.driver.find_element(by, identifier)
